pub enum Error {
Io(Error),
PluginInvoke(PluginInvokeError),
}Expand description
Errors returned by the NFC plugin.
Serializes to the error message string, so it can be returned directly from a command.
Variants
Io(Error)
An I/O error happened.
PluginInvoke(PluginInvokeError)
The call to the Android or iOS plugin implementation failed, either because the arguments could not be serialized, the response could not be deserialized or the native side rejected the call (e.g. NFC is unavailable or the tag could not be read or written).