TechKind

Enum TechKind 

pub enum TechKind {
    IsoDep,
    MifareClassic,
    MifareUltralight,
    Ndef,
    NdefFormatable,
    NfcA,
    NfcB,
    NfcBarcode,
    NfcF,
    NfcV,
}
The NFC technologies a tag can support, mirroring the android.nfc.tech classes.

Android only. Serialized as the technology name, e.g. "IsoDep".

Variants



IsoDep

ISO-DEP (ISO 14443-4) properties and I/O operations.



MifareClassic

MIFARE Classic properties and I/O operations.



MifareUltralight

MIFARE Ultralight and MIFARE Ultralight C properties and I/O operations.



Ndef

NDEF data and operations on tags that are already formatted as NDEF.



NdefFormatable

Formatting operations on tags that can be formatted as NDEF but are not yet.



NfcA

NFC-A (ISO 14443-3A) properties and I/O operations.



NfcB

NFC-B (ISO 14443-3B) properties and I/O operations.



NfcBarcode

NFC Barcode (Kovio NFC Barcode) properties and I/O operations.



NfcF

NFC-F (JIS 6319-4) properties and I/O operations.



NfcV

NFC-V (ISO 15693) properties and I/O operations.