pub enum ScanKind {
Ndef {
mime_type: Option<String>,
uri: Option<UriFilter>,
tech_list: Option<Vec<Vec<TechKind>>>,
},
Tag {
mime_type: Option<String>,
uri: Option<UriFilter>,
},
}Expand description
The kind of scan to perform, which defines which tags are matched.
Variants
Ndef
Only match tags that carry an NDEF message.
Fields

mime_type: Option<String>Only match tags whose NDEF payload has this MIME type, e.g. text/plain.
Android only.

tech_list: Option<Vec<Vec<TechKind>>>Only match tags supporting the listed technologies.
Each tech list is considered independently and the tag matches when any single tech list matches it, which provides AND (inside a list) and OR (between lists) semantics.
Android only. See https://developer.android.com/reference/android/nfc/NfcAdapter#ACTION_TECH_DISCOVERED for more information.
Tag
Match any tag that is discovered, whether it carries an NDEF message or not.